using System;
using UnityEngine;
using System.Collections.Generic;

namespace Vinput
{
    public class WindowCamAligner : MVRScript
    {
        private Atom _windowCamera;
        private Transform _navTransform;
        private JSONStorableStringChooser _hotkeyJSON;
        private KeyCode _hotkey = KeyCode.Comma;

        public static List<string> _hotkeys = Enum.GetNames(typeof(KeyCode)).ToList();

        public override void Init()
        {
            if (containingAtom.type != "WindowCamera")
            {
                SuperController.LogError($"{nameof(WindowCamAligner)}: Plugin must be attached to the WindowCamera.");
                return;
            }

            var s = SuperController.singleton;

            _windowCamera = containingAtom;
            _navTransform = SuperController.singleton.screenshotCamera.transform;

            SetupUI();

        }

        public void Update()
        {
            if (Input.GetKeyDown(_hotkey)) Align();
        }

        private void Align()
        {
            _windowCamera.transform.rotation = _navTransform.rotation;
            _windowCamera.transform.position = _navTransform.position;
            _windowCamera.transform.position += _windowCamera.transform.forward * -0.15f;

        }

        private void OnHotkeyChanged(string newKey)
        {
            _hotkey = (KeyCode)Enum.Parse(typeof(KeyCode), newKey);
        }

        private void SetupUI()
        {
            UIDynamicButton btn = CreateButton("Align");
            btn.button.onClick.AddListener(Align);

            _hotkeyJSON = new JSONStorableStringChooser("Shortcut Key", _hotkeys, "Comma", "Shortcut Key");
            RegisterStringChooser(_hotkeyJSON);
            _hotkeyJSON.setCallbackFunction += OnHotkeyChanged;
            CreateScrollablePopup(_hotkeyJSON);

            CreateTextField(new JSONStorableString("text", "Press <b>Align</b> or the shortcut key to align WindowCamera to player view."), true).height = 100;

        }
    }
}